"use strict";
//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tags = exports.Tag = void 0;
var react_1 = __importDefault(require("react"));
var lodash_1 = require("lodash");
var core_1 = require("primeobjects-helper-util/build/cjs/core");
var tooltip_1 = __importDefault(require("./tooltip"));
var colors_1 = require("primeobjects-helper-util/build/cjs/colors");
var Tag = function (props) {
    var text = props.text, tag = props.tag, onClick = props.onClick;
    var textStyle = props.textStyle ? props.textStyle : {};
    var style = props.style ? props.style : {};
    var className = props.className ? props.className : "";
    var textClassName = props.textClassName ? props.textClassName : "";
    return (react_1.default.createElement("div", { className: "py-4 px-3 ".concat(className) },
        react_1.default.createElement("div", { onClick: function () { return onClick(tag); }, className: "flex", style: __assign({ width: "max-content" }, style) },
            react_1.default.createElement("span", { className: "text-base ".concat(textClassName), style: textStyle }, text))));
};
exports.Tag = Tag;
var Tags = function (props) {
    var data = props.data, disableShorten = props.disableShorten;
    var selectedTags = (0, lodash_1.isArray)(props.selectedTags) ? props.selectedTags : [];
    var tooltipColorName = props.tooltipColorName && (0, core_1.isNonEmptyString)(props.tooltipColorName)
        ? props.tooltipColorName
        : "gray";
    var tagClassName = (0, core_1.isNonEmptyString)(props.tagClassName)
        ? props.tagClassName
        : "";
    var borderClassName = (0, core_1.isNonEmptyString)(props.borderClassName)
        ? props.borderClassName
        : "border-gray-100";
    var textStyle = props.textStyle ? props.textStyle : {};
    var tooltipColor = (0, colors_1.getColor)(tooltipColorName, 400);
    var maxLength = (0, lodash_1.isNumber)(props.maxTagLength) ? props.maxTagLength : 12;
    var className = "cursor-pointer float-left flex text-base text-gray-800 h-6 items-center rounded-lg whitespace-nowrap bg-gray-50 border-gray-100 mr-3 \n        my-1 leading-none self-center px-2 py-2 hover:text-".concat(tooltipColorName, "-800 border ").concat(borderClassName, " ").concat(tagClassName);
    var tagStyle = (0, core_1.isObject)(props.tagStyle) ? props.tagStyle : {};
    var wrapperClassName = "w-full block ".concat((0, core_1.isNonEmptyString)(props.wrapperClassName) ? props.wrapperClassName : "");
    var Tooltip = (0, lodash_1.isNil)(props.Tooltip) ? tooltip_1.default : props.Tooltip;
    var TagElement = props.Tag ? props.Tag : exports.Tag;
    var onClick = function (tag) {
        if ((0, lodash_1.isFunction)(props.onClick)) {
            props.onClick(tag);
        }
    };
    return (0, lodash_1.isArray)(data) && data.length > 0 ? (react_1.default.createElement("div", { className: wrapperClassName }, (0, lodash_1.map)((0, lodash_1.isArray)(data) ? data : [], function (tag, index) {
        var selected = (0, lodash_1.find)(selectedTags, function (selectedTag) {
            return selectedTag.toLowerCase() == tag.toLowerCase();
        });
        var textClassName = "leading-none ".concat(selected ? "search-highlight" : "", " ").concat((0, core_1.isNonEmptyString)(props.textClassName)
            ? props.textClassName
            : "");
        var shortTag = !disableShorten
            ? (0, core_1.shortenString)(tag, maxLength)
            : tag;
        if (shortTag == tag) {
            return (react_1.default.createElement(TagElement, { key: index, tag: tag, text: tag, style: __assign({ width: "max-content" }, tagStyle), className: "py-4 px-3 ".concat(className), textClassName: "text-base ".concat(textClassName), textStyle: textStyle, onClick: onClick }));
        }
        else {
            return (react_1.default.createElement(Tooltip, { key: index, color: tooltipColor, placement: "top", title: tag, wrapperClassName: "py-4 px-3 ".concat(className) },
                react_1.default.createElement(TagElement, { tag: tag, text: shortTag, className: "flex", style: __assign({ width: "max-content" }, tagStyle), textClassName: "text-base ".concat(textClassName), textStyle: textStyle, onClick: onClick })));
        }
    }))) : null;
};
exports.Tags = Tags;
exports.default = exports.Tags;
//# sourceMappingURL=tags.js.map