//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
import React, { useEffect } from "react";
import { isNonEmptyString, isSSR, getWindow, isObject } from "primeobjects-helper-util/build/cjs/core";
export var getRecaptchaToken = function (id) {
    var elemId = isNonEmptyString(id) ? "recaptcha_".concat(id) : "";
    var win = getWindow();
    try {
        return win.grecaptcha.enterprise.getResponse(win[elemId]);
    }
    catch (err) {
        console.error(err);
    }
    return undefined;
};
export var Recaptcha = function (props) {
    var siteKey = props.siteKey;
    var id = isNonEmptyString(props.id)
        ? "recaptcha_".concat(props.id)
        : "recaptcha_core";
    var scriptId = "".concat(id, "_script");
    var functionId = "".concat(id, "_onLoadRecaptcha")
        .replace(/-/g, "")
        .replace(/_/g, "");
    var style = isObject(props.style) ? props.style : {};
    var className = isNonEmptyString(props.className) ? props.className : "";
    var SSR = isSSR();
    useEffect(function () {
        if (!SSR &&
            isNonEmptyString(id) &&
            !document.getElementById(scriptId)) {
            var win_1 = getWindow();
            if (!win_1[functionId]) {
                win_1[functionId] = function () {
                    win_1[id] = win_1.grecaptcha.enterprise.render(id, {
                        sitekey: siteKey,
                        theme: "light"
                    });
                };
                win_1[scriptId] = document.createElement("script");
                win_1[scriptId].id = scriptId;
                win_1[scriptId].src = "https://www.google.com/recaptcha/enterprise.js?onload=".concat(functionId, "&render=explicit");
                document.body.appendChild(win_1[scriptId]);
            }
        }
    }, [SSR, functionId, id, scriptId, siteKey]);
    return React.createElement("div", { id: id, style: style, className: className });
};
export default Recaptcha;
//# sourceMappingURL=recaptcha.js.map